pub struct DuplexSponge<F, P, const WIDTH: usize, const RATE: usize> { /* private fields */ }Expand description
Permutation-based duplex sponge in overwrite mode.
“Duplex” refers to being able to alternately absorb (observe) and squeeze (sample), rather than a single absorb phase followed by a single squeeze phase.
This variant operates in overwrite mode, meaning new inputs overwrite state elements directly (instead of, e.g., being added in).
Implementations
Sourceimpl<F, P, const WIDTH: usize, const RATE: usize> DuplexSponge<F, P, WIDTH, RATE>
impl<F, P, const WIDTH: usize, const RATE: usize> DuplexSponge<F, P, WIDTH, RATE>
pub fn state(&self) -> &[F; WIDTH]
pub fn absorb_idx(&self) -> usize
pub fn sample_idx(&self) -> usize
Sourceimpl<F, P, const WIDTH: usize, const RATE: usize> DuplexSponge<F, P, WIDTH, RATE>where
F: Copy,
P: CryptographicPermutation<[F; WIDTH]>,
impl<F, P, const WIDTH: usize, const RATE: usize> DuplexSponge<F, P, WIDTH, RATE>where
F: Copy,
P: CryptographicPermutation<[F; WIDTH]>,